# reportr-backend-client
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.1.0
- Package version: 1.0.0
- Generator version: 7.13.0-SNAPSHOT
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import reportr_backend_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import reportr_backend_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import reportr_backend_client
from reportr_backend_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = reportr_backend_client.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: HTTPBearer
configuration = reportr_backend_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with reportr_backend_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = reportr_backend_client.NewsApi(api_client)
    news_item = reportr_backend_client.NewsItem() # NewsItem | 

    try:
        # Create News
        api_response = api_instance.create_news(news_item)
        print("The response of NewsApi->create_news:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling NewsApi->create_news: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*NewsApi* | [**create_news**](docs/NewsApi.md#create_news) | **POST** /news/ | Create News
*NewsApi* | [**get_news**](docs/NewsApi.md#get_news) | **GET** /news/ | Get News
*NewsApi* | [**get_news_by_id**](docs/NewsApi.md#get_news_by_id) | **GET** /news/{news_id} | Get News By Id
*StatusApi* | [**get_health**](docs/StatusApi.md#get_health) | **GET** /health | Health
*StatusApi* | [**get_readiness**](docs/StatusApi.md#get_readiness) | **GET** /ready | Ready


## Documentation For Models

 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [Health](docs/Health.md)
 - [NewsItem](docs/NewsItem.md)
 - [NewsItemCreated](docs/NewsItemCreated.md)
 - [PaginatedNewsResponse](docs/PaginatedNewsResponse.md)
 - [Readiness](docs/Readiness.md)
 - [TimeFilter](docs/TimeFilter.md)
 - [ValidationError](docs/ValidationError.md)
 - [ValidationErrorLocInner](docs/ValidationErrorLocInner.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="HTTPBearer"></a>
### HTTPBearer

- **Type**: Bearer authentication


## Author




